
"""
This is the package.xml data needed for the PHP OpenID PEAR
package.xml file.  Use the 'packagexml.py' program to generate a
package.xml file for a release of this library.
"""

# This is a list of dicts describing the project leads.  This will be
# used to generate <lead> XML elements.
leads = [
    {'name': 'Jonathan Daugherty',
     'user': 'cygnus',
     'email': 'cygnus@janrain.com',
     'active': 'yes'},
    {'name': 'Josh Hoyt',
     'user': 'jhoyt',
     'email': 'josh@janrain.com',
     'active': 'yes'}
    ]

# The package name.
package_name = 'Auth_OpenID'

# The package description.
package_description = 'An implementation of the OpenID single sign-on authentication protocol.'

# Package summary.
package_summary = 'PHP OpenID'

# License string.
license_name = 'Apache'

# License URI.
license_uri = 'http://www.apache.org/licenses/LICENSE-2.0'

# Director(ies) containing package source, relative to the admin/
# directory.  All .php files in these directories will be included in
# the <contents> element of the output XML and will be assigned the
# role 'php'.
contents_dirs = ['../Auth',]

# Director(ies) containing package documentation.  All files and
# subdirectories in these directories will be included in the
# <contents> element in the output XML and will be assigned the role
# 'doc'.
docs_dirs = ['../doc', '../examples']

# The HTTP package base URI.  This is the place on the web where the
# PEAR-installable tarballs will live, and this (plus the package
# tarball name) will be the URL that users pass to "pear install".
package_base_uri = 'http://www.openidenabled.com/resources/downloads/php-openid/pear/'

# The release stability.  Maybe this should be a commandline parameter
# since it might differ from release to release.
release_stability = 'stable'



"""
Fetch the current TLD list from the IANA Web site, parse it, and print
an expression suitable for direct insertion into each library's trust
root validation module

Usage:
  python gettlds.py (php|python|ruby)

Then cut-n-paste.
"""

import urllib2

import sys

langs = {
    'php': (r"'/\.(",
            "'", "|", "|' .",
            r")\.?$/'"),
    'python': ("['",
               "'", "', '", "',",
               "']"),
    'ruby': ("%w'",
             "", " ", "",
             "'"),
    }

lang = sys.argv[1]
prefix, line_prefix, separator, line_suffix, suffix = langs[lang]

f = urllib2.urlopen('http://data.iana.org/TLD/tlds-alpha-by-domain.txt')
tlds = []
output_line = ""
for input_line in f:
    if input_line.startswith('#'):
        continue

    tld = input_line.strip().lower()
    new_output_line = output_line + prefix + tld
    if len(new_output_line) > 60:
        print output_line + line_suffix
        output_line = line_prefix + tld
    else:
        output_line = new_output_line
    prefix = separator

print output_line + suffix



#!/usr/bin/python

import os
import os.path

def makeMaintainerXML(leads):
    maintainer_template = """
  <maintainer>
   <user>%(user)s</user>
   <name>%(name)s</name>
   <email>%(email)s</email>
   <role>lead</role>
  </maintainer>
  """

    return "<maintainers>" + \
           "".join([maintainer_template % l for l in leads]) + \
           "</maintainers>"

def makeLeadXML(leads):
    lead_template = """
<lead>
  <name>%(name)s</name>
  <user>%(user)s</user>
  <email>%(email)s</email>
  <active>%(active)s</active>
</lead>
    """

    return "".join([lead_template % l for l in leads])

INDENT_STRING = "  "

def buildContentsXMLFordir(dir_or_file, roles, depth=0, dir_role=None,
                           all_files=False):
    """
    Returns a list of strings, each of which is either a <file> XML
    element for the given file or a <dir> element which contains other
    <file> elements.
    """

    try:
        entries = os.listdir(dir_or_file)
        dir_role_s = ''
        if dir_role:
            dir_role_s = ' role="%s"' % (dir_role)
        lines = ['%s<dir name="%s"%s>' % (INDENT_STRING * depth,
                                          os.path.basename(dir_or_file),
                                          dir_role_s)]

        for entry in entries:
            lines += buildContentsXMLFordir(dir_or_file + os.sep + entry, roles,
                                            depth + 1, dir_role, all_files)

        lines.append('%s</dir>' % (INDENT_STRING * depth))

        return lines
    except OSError:
        try:
            extension = dir_or_file.split(".")[-1]
        except:
            if not all_files:
                return []

        if all_files and dir_role:
            return ['%s<file name="%s" role="%s" />' %
                    (INDENT_STRING * depth, os.path.basename(dir_or_file), dir_role)]
        elif extension in roles: # Ends in an extension we care about
            return ['%s<file name="%s" role="%s" />' %
                    (INDENT_STRING * depth, os.path.basename(dir_or_file),
                     roles[extension])]
        else:
            return []

def buildContentsXML(roles, *dirs):
    lines = []

    for directory in dirs:
        lines.append("\n".join(buildContentsXMLFordir(directory, roles, 1)))

    return "\n".join(lines)

def buildDocsXML(*dirs):
    lines = []

    for directory in dirs:
        lines.append("\n".join(buildContentsXMLFordir(directory, {}, 1, 'doc',
                                                      all_files=True)))

    return "\n".join(lines)

if __name__ == "__main__":
    def usage(progname):
        print "Usage: %s <package version> <xml template file> <release notes file>" % (progname)

    import sys
    import time

    try:
        import xmlconfig
    except:
        print "Could not import XML configuration module xmlconfig"
        sys.exit(1)

    # Expect sys.argv[2] to be the name of the XML file template to
    # use for processing.
    try:
        template_f = open(sys.argv[2], 'r')
    except Exception, e:
        usage(sys.argv[0])
        print "Could not open template file:", str(e)
        sys.exit(1)

    # Expect sys.argv[1] to be the version number to include in the
    # package.xml file.
    try:
        version = sys.argv[1]
    except:
        usage(sys.argv[0])
        sys.exit(2)

    # Expect sys.argv[3] to be the name of the release notes file.
    try:
        release_file = sys.argv[3]
        release_file_h = open(release_file, 'r')
        release_notes = release_file_h.read().strip()
        release_file_h.close()
    except Exception, e:
        usage(sys.argv[0])
        print str(e)
        sys.exit(3)

    data = xmlconfig.__dict__.copy()

    contentsXml = buildContentsXML({'php': 'php'}, *xmlconfig.contents_dirs)
    docsXml = buildDocsXML(*xmlconfig.docs_dirs)

    contents = '<dir name="/">\n' + contentsXml + \
               "\n" + docsXml + '\n  </dir>'

    contents_v1 = '<filelist><dir name="/" baseinstalldir="Auth">\n' + contentsXml + \
                  "\n" + docsXml + '\n  </dir></filelist>'

    data['contents'] = contents
    data['contents_version_1'] = contents_v1
    data['leads'] = makeLeadXML(xmlconfig.leads)
    data['maintainers'] = makeMaintainerXML(xmlconfig.leads)
    data['date'] = time.strftime("%Y-%m-%d")
    data['version'] = version
    data['uri'] = "%s%s-%s.tgz" % (data['package_base_uri'], data['package_name'],
                                   version)
    data['release_notes'] = release_notes

    template_data = template_f.read()
    print template_data % data



#!/usr/bin/env python

"""This script searches files for functions that are just aliases in
PHP source code. This is not 100% reliable, so it should not be
automated, but it's useful to run once in a while to make sure that
all of the matches it finds are not really legitimate aliases.

Usage:

  parse_aliases.py <name of alias file> [PHP source code filename]...
"""

import sys

# Fetch this URL to get the file that is parsed into the aliases list
alias_url = 'http://www.zend.com/phpfunc/all_aliases.php'

header_tok = '<!-- END OF HEADER -->';
footer_tok = '<!-- FOOTER -->';

# Example line of the table that we parse:
# '<tr bgcolor="#EFEFFF"><td><a href="function.bzclose.php">bzclose</a></td><td><a href="http://lxr.php.net/source/php-src/ext/bz2/bz2.c#48">php-src/ext/bz2/bz2.c</a></td><td><a href="function.fclose.php">fclose</a></td></tr>'

import re

line_re = re.compile(r'''
\A

<tr\ bgcolor="[^">]+">

<td><a\ href="[^>"]+\.php">([^<>]+)</a></td>

<td><a\ href="[^">]+">[^<>]+</a></td>

<td>
(?:
    <a\ href="[^">]+\.php">
    ( [^<>]+ )
    </a>
|   ( [^<>]+ )
)
</td>

</tr>

\Z
''', re.VERBOSE)

def parseString(s):
    _, rest = s.split(header_tok, 1)
    body, _ = rest.split(footer_tok, 1)

    lines = body.split('\n')
    assert [s.strip() for s in lines[-2:]] == ['</table>', '']
    assert lines[0].strip().startswith('<table')
    del lines[0], lines[-2:]
    aliases = {}
    for line in lines:
        mo = line_re.match(line)
        assert mo, line
        alias, master1, master2 = mo.groups()
        if master1:
            master = master1
        else:
            assert master2
            master = master2
        aliases[alias] = master

    return aliases

def parseFile(f):
    return parseString(f.read())

def parseFileName(fn):
    return parseFile(file(fn, 'r'))

def parseURL(url):
    return parseFile(urllib2.urlopen(url))

def getAliasRE(aliases):
    return re.compile(r'(->|\$|)\s*\b(%s)\b' % ('|'.join(aliases.keys())))

def checkAliasesFile(alias_re, f):
    found = []
    line_num = 1
    for line in f:
        for mo in alias_re.finditer(line):
            if mo.group(1):
                continue
            alias = mo.group(2)
            found.append((line_num, alias))
        line_num += 1
    return found

def checkAliases(alias_re, filename):
    return checkAliasesFile(alias_re, file(filename, 'r'))

def checkAliasesFiles(alias_re, filenames):
    found = []
    for filename in filenames:
        file_found = checkAliases(alias_re, filename)
        found.extend([(filename, n, a) for (n, a) in file_found])
    return found

def dumpResults(aliases, found, out=sys.stdout):
    for filename, n, a in found:
        print >>out, "%s:%d %s -> %s" % (filename, n, a, aliases[a])

def main(alias_file, *filenames):
    aliases = parseFileName(alias_file)
    alias_re = getAliasRE(aliases)
    found = checkAliasesFiles(alias_re, filenames)
    dumpResults(aliases, found)
    return found

if __name__ == '__main__':
    found = main(*sys.argv[1:])
    if found:
        sys.exit(1)
